import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * CloudFormation template for Pro Database.
 *
 * @schema CfnProDatabaseProps
 */
export interface CfnProDatabaseProps {
    /**
     * [Required]. The Base URL where the API calls are sent.
     *
     * @schema CfnProDatabaseProps#BaseUrl
     */
    readonly baseUrl?: string;
    /**
     * [Required]. The Subscription ID under which the Database is created.
     *
     * @schema CfnProDatabaseProps#SubscriptionID
     */
    readonly subscriptionId: string;
    /**
     * [Optional]. When 'false': Creates a deployment plan and deploys it (creating any resources required by the plan). When 'true': creates a read-only deployment plan without any resource creation. Example: false. Default: 'false'.
     *
     * @schema CfnProDatabaseProps#DryRun
     */
    readonly dryRun?: string;
    /**
     * [Required]. Database name (Database name must be up to 40 characters long, include only letters, digits, or hyphen ('-'), start with a letter, and end with a letter or digit). Example: Redis-database-example
     *
     * @schema CfnProDatabaseProps#DatabaseName
     */
    readonly databaseName: string;
    /**
     * [Optional]. Database protocol: either 'redis' or 'memcached'. Default: 'redis'
     *
     * @schema CfnProDatabaseProps#Protocol
     */
    readonly protocol?: string;
    /**
     * [Optional]. TCP port on which the database is available (10000-19999). Generated automatically if omitted. Example: 10000
     *
     * @schema CfnProDatabaseProps#Port
     */
    readonly port?: string;
    /**
     * [Required]. The maximum amount of data in the dataset for this specific database is in GB. You can not set both datasetSizeInGb and totalMemoryInGb. if 'replication' is true, the database's total memory will be twice as large as the datasetSizeInGb.if 'replication' is false, the database's total memory of the database will be the datasetSizeInGb value. Minimum: 0.1. ExclusiveMinimum: false. Example: 1
     *
     * @schema CfnProDatabaseProps#DatasetSizeInGb
     */
    readonly datasetSizeInGb: string;
    /**
     * [Optional]. RESP version must be compatible with Redis version. Example: resp3. Allowed values: resp2/resp3.
     *
     * @schema CfnProDatabaseProps#RespVersion
     */
    readonly respVersion?: string;
    /**
     * [Optional]. Support Redis open-source (OSS) Cluster API. Default: 'false'
     *
     * @schema CfnProDatabaseProps#SupportOSSClusterApi
     */
    readonly supportOssClusterApi?: string;
    /**
     * [Optional]. Should use external endpoint for open-source (OSS) Cluster API. Can only be enabled if OSS Cluster API support is enabled'. Default: 'false'
     *
     * @schema CfnProDatabaseProps#UseExternalEndpointForOSSClusterApi
     */
    readonly useExternalEndpointForOssClusterApi?: string;
    /**
     * [Optional]. Rate of database data persistence (in persistent storage). List of options: [ none, aof-every-1-second, aof-every-write, snapshot-every-1-hour, snapshot-every-6-hours, snapshot-every-12-hours ]. Example: none. Default: 'none'.
     *
     * @schema CfnProDatabaseProps#DataPersistence
     */
    readonly dataPersistence?: string;
    /**
     * [Optional]. Data items eviction method. List of options: [ allkeys-lru, allkeys-lfu, allkeys-random, volatile-lru, volatile-lfu, volatile-random, volatile-ttl, noeviction ]. Default: 'volatile-lru'
     *
     * @schema CfnProDatabaseProps#DataEvictionPolicy
     */
    readonly dataEvictionPolicy?: string;
    /**
     * [Optional]. Databases replication. Default: 'true'
     *
     * @schema CfnProDatabaseProps#Replication
     */
    readonly replication?: string;
    /**
     * [Optional. Input as JSON]. Replica Of configuration
     *
     * @schema CfnProDatabaseProps#Replica
     */
    readonly replica?: string;
    /**
     * [Optional. Input as JSON]. Throughput measurement method. Default: 25000 ops/sec
     *
     * @schema CfnProDatabaseProps#ThroughputMeasurement
     */
    readonly throughputMeasurement?: string;
    /**
     * [Optional. Input as JSON]. Throughput measurement for an active-active subscription
     *
     * @schema CfnProDatabaseProps#LocalThroughputMeasurement
     */
    readonly localThroughputMeasurement?: string;
    /**
     * [Optional]. Relevant only to ram-and-flash clusters. Estimated average size (measured in bytes) of the items stored in the database. Default: 1000
     *
     * @schema CfnProDatabaseProps#AverageItemSizeInBytes
     */
    readonly averageItemSizeInBytes?: string;
    /**
     * [Optional. Input as JSON]. Database remote backup configuration
     *
     * @schema CfnProDatabaseProps#RemoteBackup
     */
    readonly remoteBackup?: string;
    /**
     * [Optional]. List of source IP addresses or subnet masks. If specified, Redis clients will be able to connect to this database only from within the specified source IP addresses ranges. Example value: '['192.168.10.0/32', '192.168.12.0/24']'
     *
     * @schema CfnProDatabaseProps#SourceIp
     */
    readonly sourceIp?: string;
    /**
     * [Optional. Input as a JSON]. A list of TLS/SSL certificates (public keys) with new line characters replaced by
     * . If specified, mTLS authentication (with enableTls not specified or set to true) will be required to authenticate user connections. If empty list is received, SSL certificates will be removed and mTLS will not be required (note that TLS connection may still apply, depending on the value of the enableTls property). Default: 'null'
     *
     * @schema CfnProDatabaseProps#ClientTlsCertificates
     */
    readonly clientTlsCertificates?: string;
    /**
     * [Optional]. When 'true', requires TLS authentication for all connections (mTLS with valid clientSslCertificate, regular TLS when the clientSslCertificate is not provided. Default: 'false'
     *
     * @schema CfnProDatabaseProps#EnableTls
     */
    readonly enableTls?: string;
    /**
     * [Optional]. Password to access the database. If omitted, a random 32 character long alphanumeric password will be automatically generated. Can only be set if Database Protocol is REDIS
     *
     * @schema CfnProDatabaseProps#Password
     */
    readonly password?: string;
    /**
     * [Optional]. Memcached (SASL) Username to access the database. If omitted, the username will be set to a 'mc-' prefix followed by a random 5 character long alphanumeric. Can only be set if Database Protocol is MEMCACHED
     *
     * @schema CfnProDatabaseProps#SaslUsername
     */
    readonly saslUsername?: string;
    /**
     * [Optional]. Memcached (SASL) Password to access the database. If omitted, a random 32 character long alphanumeric password will be automatically generated. Can only be set if Database Protocol is MEMCACHED
     *
     * @schema CfnProDatabaseProps#SaslPassword
     */
    readonly saslPassword?: string;
    /**
     * [Optional. Input as JSON]. Redis database alerts.
     *
     * @schema CfnProDatabaseProps#Alerts
     */
    readonly alerts?: string;
    /**
     * [Optional. Input as JSON]. Redis modules to be provisioned in the database.
     *
     * @schema CfnProDatabaseProps#Modules
     */
    readonly modules?: string;
    /**
     * [Optional]. The query performance factor adds extra compute power specifically for search and query. For databases with search and query, you can increase your search queries per second by the selected factor. Example: 2x
     *
     * @schema CfnProDatabaseProps#QueryPerformanceFactor
     */
    readonly queryPerformanceFactor?: string;
    /**
     * [Optional. Can only be modified upon Update request from a Cloud Formation stack]. Shard regex rules. Relevant only for a sharded database.
     *
     * @schema CfnProDatabaseProps#RegexRules
     */
    readonly regexRules?: string;
    /**
     * [Optional. Can only be modified upon Update request from a Cloud Formation stack]. When 'true', enables connecting to the database with the 'default' user. Default: 'true'. Can only be set if Database Protocol is REDIS
     *
     * @schema CfnProDatabaseProps#EnableDefaultUser
     */
    readonly enableDefaultUser?: string;
    /**
     * [Required to enable Backup. Can only be modified upon Update request from a Cloud Formation stack. Requires 'remoteBackup' to be active]. If 'true', creates a backup of the current database and disables all other parameters set for Update except for 'RegionName'. Default 'false'.
     *
     * @schema CfnProDatabaseProps#OnDemandBackup
     */
    readonly onDemandBackup?: string;
    /**
     * [Optional. Can only be modified upon Update request from a Cloud Formation stack. Requires 'OnDemandBackup' set to 'true']. Name of cloud provider region where the local database is located. When backing up an active-active database, backup is done separately for each local database at a specified region. Example for active-active database: 'us-east-1'. For single-region deployment, the value MUST be 'null'.
     *
     * @schema CfnProDatabaseProps#RegionName
     */
    readonly regionName?: string;
    /**
     * [Required to enable Import. Can only be modified upon Update request from a Cloud Formation stack]. If 'true', imports the previous created backup of a database and disables all other parameters set for Update except for 'SourceType' and 'ImportFromUri'. Default 'false'.
     *
     * @schema CfnProDatabaseProps#OnDemandImport
     */
    readonly onDemandImport?: string;
    /**
     * [Required for Import. Can only be modified upon Update request from a Cloud Formation stack. Requires 'OnDemandImport' set to 'true']. Type of storage source from which to import the database file (RDB files) or data (Redis connection). List of options: [ http, redis, ftp, aws-s3, azure-blob-storage, google-blob-storage ].
     *
     * @schema CfnProDatabaseProps#SourceType
     */
    readonly sourceType?: string;
    /**
     * [Required for Import. Can only be modified upon Update request from a Cloud Formation stack. Requires 'OnDemandImport' set to 'true'].  One or more URIs to source data files or Redis databases, as appropriate to specified source type (example: ['http://mydomain.com/redis-backup-file1', 'http://mydomain.com/redis-backup-file2'])
     *
     * @schema CfnProDatabaseProps#ImportFromUri
     */
    readonly importFromUri?: string;
}
/**
 * Converts an object of type 'CfnProDatabaseProps' to JSON representation.
 */
export declare function toJson_CfnProDatabaseProps(obj: CfnProDatabaseProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Redis::CloudFormation::ProDatabase`
 *
 * @cloudformationResource Redis::CloudFormation::ProDatabase
 * @stability external
 * @link http://unknown-url
 */
export declare class CfnProDatabase extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Redis::CloudFormation::ProDatabase";
    /**
     * Resource props.
     */
    readonly props: CfnProDatabaseProps;
    /**
     * Attribute `Redis::CloudFormation::ProDatabase.DatabaseID`
     * @link http://unknown-url
     */
    readonly attrDatabaseID: string;
    /**
     * Create a new `Redis::CloudFormation::ProDatabase`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnProDatabaseProps);
}
